@@ -58,53 +58,21 @@ $F->cls('OFF');
 
 print_it($F,'Color Mapping Test -> Red-Green-Blue');
 {
-    my $third = int($XX / 3);
-    $F->set_color(
-        {
-            'red'   => 255,
-            'green' => 0,
-            'blue'  => 0,
-        }
-    );
     $F->rbox(
         {
             'filled' => 1,
             'x'      => 0,
             'y'      => 0,
-            'width'  => $third,
-            'height' => $YY
-        }
-    );
-    $F->set_color(
-        {
-            'red'   => 0,
-            'green' => 255,
-            'blue'  => 0,
-        }
-    );
-    $F->rbox(
-        {
-            'filled' => 1,
-            'x'      => $third,
-            'y'      => 0,
-            'width'  => $third,
-            'height' => $YY
-        }
-    );
-    $F->set_color(
-        {
-            'red'   => 0,
-            'green' => 0,
-            'blue'  => 255,
-        }
-    );
-    $F->rbox(
-        {
-            'filled' => 1,
-            'x'      => $third * 2,
-            'y'      => 0,
-            'width'  => $third,
-            'height' => $YY
+            'width'  => $XX,
+            'height' => $YY,
+            'gradient' => {
+                'direction' => 'horizontal',
+                'colors' => {
+                    'red'   => [255,0,0],
+                    'green' => [0,255,0],
+                    'blue'  => [0,0,255]
+                }
+            }
         }
     );
 #    sleep $factor;
