@@ -11,6 +11,9 @@ use Graphics::Framebuffer;
 use Time::HiRes qw(sleep time);
 # use Data::Dumper::Simple;$Data::Dumper::Sortkeys=1;
 
+$SIG{'QUIT'} = sub {exec('reset');};
+$SIG{'INT'}  = sub {exec('reset');};
+
 my $args = join('',@ARGV);
 
 my $file = 0;
@@ -41,15 +44,17 @@ my %p = (
 my $image = $f->load_image(\%p);
 # warn ref($image),"\n\n",Dumper($image),"\n\n";exit;
 if (ref($image) eq 'ARRAY') {
-    foreach my $t (1 .. 2) {
+    while(1) {
         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
+            my $begin = time;
             $f->blit_write($image->[$frame]);
-            sleep ($image->[$frame]->{'tags'}->{'gif_delay'} / 100);
+            my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100) - (time - $begin);
+            sleep $delay if ($delay > 0);
         }
     }
 } else {
     $f->blit_write($image);
 }
-sleep 1;
+sleep 3;
 $f->cls('ON');
 
